package com.ruoxitech.mobsdk_plugin

import android.util.Log
import androidx.annotation.NonNull
import com.mob.MobSDK
import com.mob.OperationCallback

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** MobsdkPlugin */
class MobsdkPlugin: FlutterPlugin, MethodCallHandler {

  private val TAG = MobsdkPlugin::class.java.simpleName

  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "mobsdk_plugin")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    when (call.method) {
        "getPlatformVersion" -> {
          result.success("Android ${android.os.Build.VERSION.RELEASE}")
        }
        "submitPolicyGrantResult" -> {
          submitPolicyGrantResult(call)
        }
        else -> { result.notImplemented()
        }
    }
  }

  private fun submitPolicyGrantResult(call: MethodCall) {
      val granted = call.argument<Boolean>("isGranted")
      Log.d(TAG, "onMethodCall---submitPolicyGrantResult---granted: $granted")
      granted ?: return
      val callback = object : OperationCallback<Void>() {
          override fun onComplete(p0: Void?) {
              Log.d(TAG, "onMethodCall---submitPolicyGrantResult---p0: $p0")
          }

          override fun onFailure(e: Throwable?) {
              Log.d(TAG, "onMethodCall---submitPolicyGrantResult---e: $e  ")
          }

      }
      MobSDK.submitPolicyGrantResult(granted, callback)
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
